@@ -64,8 +64,6 @@ Bomber::Bomber()
 
     setFocus();
     setupGUI();
-
-    // readSettings();
 }
 
 Bomber::~Bomber()
@@ -111,15 +109,15 @@ void Bomber::newGame()
 {
     // Check for running game
     closeGame();
-    if (m_gameWidget->state() == BomberGameWidget::BeforeFirstGame
-            || m_gameWidget->state() == BomberGameWidget::GameOver) {
+    if (m_gameWidget->state() == BomberGameWidget::State::BeforeFirstGame
+            || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
         m_gameWidget->newGame();
     }
 }
 
 void Bomber::pauseGame()
 {
-    if (m_gameWidget->state() == BomberGameWidget::Paused) {
+    if (m_gameWidget->state() == BomberGameWidget::State::Paused) {
         m_gameWidget->setPaused(false);
     } else {
         m_gameWidget->setPaused(true);
@@ -128,13 +126,13 @@ void Bomber::pauseGame()
 
 void Bomber::closeGame()
 {
-    if (m_gameWidget->state() == BomberGameWidget::BeforeFirstGame
-            || m_gameWidget->state() == BomberGameWidget::GameOver) {
+    if (m_gameWidget->state() == BomberGameWidget::State::BeforeFirstGame
+            || m_gameWidget->state() == BomberGameWidget::State::GameOver) {
         return;
     }
 
     BomberGameWidget::State old_state = m_gameWidget->state();
-    if (old_state == BomberGameWidget::Running) {
+    if (old_state == BomberGameWidget::State::Running) {
         m_gameWidget->setPaused(true);
     }
     int ret = KMessageBox::questionYesNo(this, i18nc("Message displayed when play tries to quit a game that is currently running",
@@ -142,7 +140,7 @@ void Bomber::closeGame()
                                          KStandardGuiItem::close(), KStandardGuiItem::cancel());
     if (ret == KMessageBox::Yes) {
         m_gameWidget->closeGame();
-    } else if (old_state == BomberGameWidget::Running) {
+    } else if (old_state == BomberGameWidget::State::Running) {
         m_gameWidget->setPaused(false);
     }
 }
@@ -158,14 +156,15 @@ void Bomber::showHighscore()
 
 void Bomber::highscore()
 {
-    KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this);
+    QPointer<KScoreDialog> ksdialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this);
 
     KScoreDialog::FieldInfo info;
     info[KScoreDialog::Score].setNum(m_gameWidget->score());
     info[KScoreDialog::Level].setNum(m_gameWidget->level());
-    if (ksdialog.addScore(info)) {
-        ksdialog.exec();
+    if (ksdialog->addScore(info)) {
+        ksdialog->exec();
     }
+    delete ksdialog;
 }
 
 void Bomber::setSounds(bool val)
@@ -198,16 +197,15 @@ void Bomber::displayLives(unsigned int lives)
 void Bomber::gameStateChanged(BomberGameWidget::State state)
 {
     switch (state) {
-
-    case BomberGameWidget::Paused:
+    case BomberGameWidget::State::Paused:
         m_pauseAction->setChecked(true);
         m_statusBar->clearMessage();
         break;
-    case BomberGameWidget::Running:
+    case BomberGameWidget::State::Running:
         m_pauseAction->setChecked(false);
         m_statusBar->clearMessage();
         break;
-    case BomberGameWidget::GameOver:
+    case BomberGameWidget::State::GameOver:
         m_statusBar->showMessage(i18nc("Game over messaged displayed in the status bar", "Game over. Press '%1' for a new game",
                                        m_newAction->shortcuts().first().toString(QKeySequence::NativeText)));
         highscore();
