@@ -49,11 +49,11 @@ void Plane::resetPosition()
 
 void Plane::advanceItem()
 {
-    if (state() == Moving) {
+    if (state() == State::Moving) {
         m_xPos += velocity();
         if (m_xPos > PLANE_MAX_POSITION_X) {
             m_xPos = 0;
-            m_yPos++;
+            ++m_yPos;
         }
     }
     m_nextBoundingRect.moveTo(m_xPos + velocity(), m_yPos);
